.. _sdv.constraints.tabular:

Tabular Constraints
===================

.. currentmodule:: sdv.constraints

FixedCombinations
~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

   FixedCombinations
   FixedCombinations.fit
   FixedCombinations.transform
   FixedCombinations.fit_transform
   FixedCombinations.reverse_transform
   FixedCombinations.is_valid
   FixedCombinations.filter_valid
   FixedCombinations.from_dict
   FixedCombinations.to_dict

Inequality
~~~~~~~~~~

.. autosummary::
   :toctree: api/

   Inequality
   Inequality.fit
   Inequality.transform
   Inequality.fit_transform
   Inequality.reverse_transform
   Inequality.is_valid
   Inequality.filter_valid
   Inequality.from_dict
   Inequality.to_dict

ScalarInequality
~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

   ScalarInequality
   ScalarInequality.fit
   ScalarInequality.transform
   ScalarInequality.fit_transform
   ScalarInequality.reverse_transform
   ScalarInequality.is_valid
   ScalarInequality.filter_valid
   ScalarInequality.from_dict
   ScalarInequality.to_dict

Positive
~~~~~~~~

.. autosummary::
   :toctree: api/

   Positive
   Positive.fit
   Positive.transform
   Positive.fit_transform
   Positive.reverse_transform
   Positive.is_valid
   Positive.filter_valid
   Positive.from_dict
   Positive.to_dict

Negative
~~~~~~~~

.. autosummary::
   :toctree: api/

   Negative
   Negative.fit
   Negative.transform
   Negative.fit_transform
   Negative.reverse_transform
   Negative.is_valid
   Negative.filter_valid
   Negative.from_dict
   Negative.to_dict

Range
~~~~~

.. autosummary::
   :toctree: api/

   Range
   Range.fit
   Range.transform
   Range.fit_transform
   Range.reverse_transform
   Range.is_valid
   Range.filter_valid
   Range.from_dict
   Range.to_dict

ScalarRange
~~~~~~~~~~~

.. autosummary::
   :toctree: api/

   ScalarRange
   ScalarRange.fit
   ScalarRange.transform
   ScalarRange.fit_transform
   ScalarRange.reverse_transform
   ScalarRange.is_valid
   ScalarRange.filter_valid
   ScalarRange.from_dict
   ScalarRange.to_dict

OneHotEncoding
~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

   OneHotEncoding
   OneHotEncoding.fit
   OneHotEncoding.transform
   OneHotEncoding.fit_transform
   OneHotEncoding.reverse_transform
   OneHotEncoding.is_valid
   OneHotEncoding.filter_valid
   OneHotEncoding.from_dict
   OneHotEncoding.to_dict

Unique
~~~~~~

.. autosummary::
   :toctree: api/

   Unique
   Unique.fit
   Unique.transform
   Unique.fit_transform
   Unique.reverse_transform
   Unique.is_valid
   Unique.filter_valid
   Unique.from_dict
   Unique.to_dict
